@@ -10,7 +10,7 @@ except ImportError:
     import dummy_threading as threading
 
 from collections import Sequence, defaultdict
-from errno import EINVAL, ENOENT
+from errno import EINVAL, ENOENT, EEXIST
 from functools import wraps
 from itertools import chain, count
 from operator import attrgetter
@@ -30,6 +30,11 @@ else:
         _getfinalpathname = None
 
 
+__all__ = [
+    "PurePath", "PurePosixPath", "PureNTPath",
+    "Path", "PosixPath", "NTPath",
+    ]
+
 #
 # Internals
 #
@@ -253,8 +258,8 @@ class _Accessor:
 
 # We need all of these
 _at_functions = [
-    'fchmodat', 'fdlistdir', 'fstatat', 'openat', 'readlinkat', 'renameat',
-    'symlinkat', 'unlinkat',
+    'fchmodat', 'fdlistdir', 'fstatat', 'mkdirat', 'openat', 'readlinkat',
+    'renameat', 'symlinkat', 'unlinkat',
     ]
 supports_openat = all(hasattr(os, fn) for fn in _at_functions)
 
@@ -263,7 +268,7 @@ if supports_openat:
     _AT_SYMLINK_NOFOLLOW = os.AT_SYMLINK_NOFOLLOW
     _AT_REMOVE_DIR = os.AT_REMOVEDIR
 
-    def fdnamepair(pathobj):
+    def _fdnamepair(pathobj):
         """Get a (parent fd, name) pair from a path object, suitable for use
         with the various *at functions."""
         parent_fd = pathobj._parent_fd
@@ -278,17 +283,17 @@ if supports_openat:
         def _wrap_atfunc(atfunc):
             @wraps(atfunc)
             def wrapped(pathobj, *args):
-                parent_fd, name = fdnamepair(pathobj)
+                parent_fd, name = _fdnamepair(pathobj)
                 return atfunc(parent_fd, name, *args)
             return staticmethod(wrapped)
 
         def _wrap_binary_atfunc(atfunc):
             @wraps(atfunc)
             def wrapped(pathobjA, pathobjB, *args):
-                parent_fd_A, nameA = fdnamepair(pathobjA)
+                parent_fd_A, nameA = _fdnamepair(pathobjA)
                 # We allow pathobjB to be a plain str, for convenience
                 if isinstance(pathobjB, Path):
-                    parent_fd_B, nameB = fdnamepair(pathobjB)
+                    parent_fd_B, nameB = _fdnamepair(pathobjB)
                 else:
                     # If it's a str then at best it's cwd-relative
                     parent_fd_B, nameB = _NO_FD, str(pathobjB)
@@ -307,6 +312,8 @@ if supports_openat:
         def lchmod(self, pathobj, mode):
             return self.chmod(pathobj, mode, _AT_SYMLINK_NOFOLLOW)
 
+        mkdir = _wrap_atfunc(os.mkdirat)
+
         unlink = _wrap_atfunc(os.unlinkat)
 
         def rmdir(self, pathobj):
@@ -319,7 +326,7 @@ if supports_openat:
         rename = _wrap_binary_atfunc(os.renameat)
 
         def symlink(self, target, pathobj):
-            parent_fd, name = fdnamepair(pathobj)
+            parent_fd, name = _fdnamepair(pathobj)
             os.symlinkat(str(target), parent_fd, name)
 
         def _make_fd(self, pathobj, tolerant=True):
@@ -431,6 +438,8 @@ class _NormalAccessor(_Accessor):
         def lchmod(self, pathobj, mode):
             raise NotImplementedError("lchmod() not available on this system")
 
+    mkdir = _wrap_strfunc(os.mkdir)
+
     unlink = _wrap_strfunc(os.unlink)
 
     rmdir = _wrap_strfunc(os.rmdir)
@@ -720,6 +729,8 @@ class PurePath:
 
     def parent(self, level=1):
         """A parent or ancestor (if `level` is specified) of this path."""
+        if level < 1:
+            raise ValueError("`level` must be a non-zero positive integer")
         drv = self._drv
         root = self._root
         parts = self._parts[:-level]
@@ -1004,6 +1015,32 @@ class Path(PurePath):
         else:
             return io.open(str(self), mode, buffering, encoding, errors, newline)
 
+    def touch(self, mode=0o777, exist_ok=True):
+        """
+        Create this file with the given access mode, if it doesn't exist.
+        """
+        if self._closed:
+            self._raise_closed()
+        flags = os.O_CREAT
+        if not exist_ok:
+            flags |= os.O_EXCL
+        fd = self.raw_open(flags, mode)
+        os.close(fd)
+
+    def mkdir(self, mode=0o777, parents=False):
+        if self._closed:
+            self._raise_closed()
+        if not parents:
+            self._accessor.mkdir(self, mode)
+        else:
+            try:
+                self._accessor.mkdir(self, mode)
+            except OSError as e:
+                if e.errno != ENOENT:
+                    raise
+                self.parent().mkdir(mode, True)
+                self._accessor.mkdir(self, mode)
+
     def chmod(self, mode):
         """
         Change the permissions of the path, like os.chmod().
